Method: Worldline::Acquiring::SDK::CommunicatorConfiguration#max_connections

Defined in:
lib/worldline/acquiring/sdk/communicator_configuration.rb,
lib/worldline/acquiring/sdk/communicator_configuration.rb

#max_connectionsInteger

The number of connections with the Worldline Acquiring platform that are kept alive in the connection pool. These connections will be reused when possible.

Returns:

  • (Integer)

    the current value of max_connections



23
24
25
# File 'lib/worldline/acquiring/sdk/communicator_configuration.rb', line 23

def max_connections
  @max_connections
end